Crate ethrex_l2_sdk

Crate ethrex_l2_sdk 

Re-exports

pub use l1_to_l2_tx_data::L1ToL2TransactionData;
pub use l1_to_l2_tx_data::send_l1_to_l2_tx;

Modules

calldata
l1_to_l2_tx_data
privileged_data

Structs

ProxyDeployment

Enums

ContractCompilationError
DeployError
GitError
SdkError

Constants

ADDRESS_ALIASING
COMMON_BRIDGE_L2_ADDRESS
CREATE2DEPLOYER_ADDRESS
DEFAULT_BRIDGE_ADDRESS
DETERMINISTIC_DEPLOYMENT_PROXY_ADDRESS
FEE_TOKEN_PRICER_ADDRESS
FEE_TOKEN_REGISTRY_ADDRESS
L2_TO_L1_MESSENGER_ADDRESS
L2_WITHDRAW_SIGNATURE
REGISTER_FEE_TOKEN_SIGNATURE
RISC0_VERIFIER_ID
Verifier ID for RISC0 proofs in the OnChainProposer verificationKeys mapping.
SAFE_SINGLETON_FACTORY_ADDRESS
SET_FEE_TOKEN_RATIO_SIGNATURE
SP1_VERIFIER_ID
Verifier ID for SP1 proofs in the OnChainProposer verificationKeys mapping.

Functions

add_blobs_to_generic_tx
address_to_word
bridge_address
BRIDGE_ADDRESS or 0x797b347d2209f7dcb8f9bb68fe4296a05d5a2c2b
build_generic_tx
Build a GenericTransaction with the given parameters. Either overrides.nonce or overrides.from must be provided. If overrides.gas_price, overrides.chain_id or overrides.gas_price are not provided, the client will fetch them from the network. If overrides.gas_limit is not provided, the client will estimate the tx cost.
call_contract
claim_erc20withdraw
claim_withdraw
compile_contract
create2_deploy_from_bytecode
create2_deploy_from_bytecode_no_wait
create2_deploy_from_path
create_deploy
deploy_with_proxy
Deploys a contract behind an OpenZeppelin’s ERC1967Proxy.
deploy_with_proxy_from_bytecode
Same as deploy_with_proxy, but takes the contract bytecode directly instead of a path.
deploy_with_proxy_from_bytecode_no_wait
Same as deploy_with_proxy_from_bytecode, but does not wait for the transaction receipts.
deploy_with_proxy_no_wait
Same as deploy_with_proxy, but does not wait for the transaction receipts.
deposit_erc20
deposit_through_transfer
get_address_alias
get_batch_commit_hash
Gets the commit hash for a batch from the batchCommitments mapping.
get_erc1967_slot
get_fee_token_ratio
get_l1_active_fork
get_l2_gas_limit
get_last_committed_batch
get_last_fetched_l1_block
get_last_verified_batch
get_pending_l1_messages
get_pending_l2_messages
get_risc0_vk_for_batch
Gets the RISC0 verification key for a specific batch from the verificationKeys mapping. This fetches the commit hash from batchCommitments and then gets the VK.
get_sp1_vk_for_batch
Gets the SP1 verification key for a specific batch from the verificationKeys mapping. This fetches the commit hash from batchCommitments and then gets the VK.
get_verification_key
Gets the verification key from the verificationKeys(commitHash, verifierId) mapping.
git_clone
initialize_contract_no_wait
register_fee_token_no_wait
secret_key_deserializer
secret_key_serializer
send_generic_transaction
send_tx_bump_gas_exponential_backoff
transfer
wait_for_l1_message_proof
wait_for_l2_deposit_receipt
wait_for_transaction_receipt
withdraw