Re-exports
pub use l1_to_l2_tx_data::L1ToL2TransactionData;pub use l1_to_l2_tx_data::send_l1_to_l2_tx;
Modules
Structs
Enums
Constants
- ADDRESS_
ALIASING - COMMON_
BRIDGE_ L2_ ADDRESS - CREAT
E2DEPLOYER_ ADDRESS - DEFAULT_
BRIDGE_ ADDRESS - DETERMINISTIC_
DEPLOYMENT_ PROXY_ ADDRESS - FEE_
TOKEN_ PRICER_ ADDRESS - FEE_
TOKEN_ REGISTRY_ ADDRESS - L2_
TO_ L1_ MESSENGER_ ADDRESS - L2_
WITHDRAW_ SIGNATURE - REGISTER_
FEE_ TOKEN_ SIGNATURE - RISC0_
VERIFIER_ ID - Verifier ID for RISC0 proofs in the OnChainProposer verificationKeys mapping.
- SAFE_
SINGLETON_ FACTORY_ ADDRESS - SET_
FEE_ TOKEN_ RATIO_ SIGNATURE - SP1_
VERIFIER_ ID - Verifier ID for SP1 proofs in the OnChainProposer verificationKeys mapping.
Functions
- add_
blobs_ to_ generic_ tx - address_
to_ word - bridge_
address - BRIDGE_ADDRESS or 0x797b347d2209f7dcb8f9bb68fe4296a05d5a2c2b
- build_
generic_ tx - Build a GenericTransaction with the given parameters.
Either
overrides.nonceoroverrides.frommust be provided. Ifoverrides.gas_price,overrides.chain_idoroverrides.gas_priceare not provided, the client will fetch them from the network. Ifoverrides.gas_limitis not provided, the client will estimate the tx cost. - call_
contract - claim_
erc20withdraw - claim_
withdraw - compile_
contract - create2_
deploy_ from_ bytecode - create2_
deploy_ from_ bytecode_ no_ wait - create2_
deploy_ from_ path - create_
deploy - deploy_
with_ proxy - Deploys a contract behind an OpenZeppelin’s
ERC1967Proxy. - deploy_
with_ proxy_ from_ bytecode - Same as
deploy_with_proxy, but takes the contract bytecode directly instead of a path. - deploy_
with_ proxy_ from_ bytecode_ no_ wait - Same as
deploy_with_proxy_from_bytecode, but does not wait for the transaction receipts. - deploy_
with_ proxy_ no_ wait - Same as
deploy_with_proxy, but does not wait for the transaction receipts. - deposit_
erc20 - deposit_
through_ transfer - get_
address_ alias - get_
batch_ commit_ hash - Gets the commit hash for a batch from the batchCommitments mapping.
- get_
erc1967_ slot - get_
fee_ token_ ratio - get_
l1_ active_ fork - get_
l2_ gas_ limit - get_
last_ committed_ batch - get_
last_ fetched_ l1_ block - get_
last_ verified_ batch - get_
pending_ l1_ messages - get_
pending_ l2_ messages - get_
risc0_ vk_ for_ batch - Gets the RISC0 verification key for a specific batch from the verificationKeys mapping. This fetches the commit hash from batchCommitments and then gets the VK.
- get_
sp1_ vk_ for_ batch - Gets the SP1 verification key for a specific batch from the verificationKeys mapping. This fetches the commit hash from batchCommitments and then gets the VK.
- get_
verification_ key - Gets the verification key from the verificationKeys(commitHash, verifierId) mapping.
- git_
clone - initialize_
contract_ no_ wait - register_
fee_ token_ no_ wait - secret_
key_ deserializer - secret_
key_ serializer - send_
generic_ transaction - send_
tx_ bump_ gas_ exponential_ backoff - transfer
- wait_
for_ l1_ message_ proof - wait_
for_ l2_ deposit_ receipt - wait_
for_ transaction_ receipt - withdraw